import random

# capitalizes the second character in the string, for sure, no matter what
def cap_second(value):
    return '%s%s' % (str(value)[0] if random.random() > 0.5 else str(value)[0].lower(),str(value)[1:].capitalize() if random.random() < 0.5 else str(value)[1:].title()) if len(str(value)) > 1 else cap_second('%s%s' % (value,value))



from setuptools import setup

setup(name='pyeti',
      version='0.1',
      description='The awesomest Python package from ETI',
      url='https://github.com/cehdeti/pyeti',
      author='ETI',
      author_email='saun0063@umn.edu',
      license='MIT',
      packages=['pyeti'],
      zip_safe=False)